        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 24 <br>1,2,5,6,8,9,11,12,16,18,19,20,24,26,28,35,37,38,39,40,41,42,44,46';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 14 <strong>control</strong><br>0,4,7,10,13,21,22,32,33,34,36,43,48,50';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 13 <br>3,14,15,17,23,25,27,29,30,31,45,47,49';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 24 <br>1,2,5,6,8,9,11,12,16,18,19,20,24,26,28,35,37,38,39,40,41,42,44,46';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 14 <strong>control</strong><br>0,4,7,10,13,21,22,32,33,34,36,43,48,50';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 13 <br>3,14,15,17,23,25,27,29,30,31,45,47,49';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 24 <br>1,2,5,6,8,9,11,12,16,18,19,20,24,26,28,35,37,38,39,40,41,42,44,46';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 14 <strong>control</strong><br>0,4,7,10,13,21,22,32,33,34,36,43,48,50';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 13 <br>3,14,15,17,23,25,27,29,30,31,45,47,49';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 24 <br>1,2,5,6,8,9,11,12,16,18,19,20,24,26,28,35,37,38,39,40,41,42,44,46';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 14 <strong>control</strong><br>0,4,7,10,13,21,22,32,33,34,36,43,48,50';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 13 <br>3,14,15,17,23,25,27,29,30,31,45,47,49';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 24 <br>1,2,5,6,8,9,11,12,16,18,19,20,24,26,28,35,37,38,39,40,41,42,44,46';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 14 <strong>control</strong><br>0,4,7,10,13,21,22,32,33,34,36,43,48,50';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 13 <br>3,14,15,17,23,25,27,29,30,31,45,47,49';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>6</strong> miembros: 24 <br>1,2,5,6,8,9,11,12,16,18,19,20,24,26,28,35,37,38,39,40,41,42,44,46';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 14 <strong>control</strong><br>0,4,7,10,13,21,22,32,33,34,36,43,48,50';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260614 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>15</strong> miembros: 13 <br>3,14,15,17,23,25,27,29,30,31,45,47,49';}
}
